@@ -1,7 +1,7 @@
 """
 Type annotations for ec2 service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/literals/)
 
 Usage::
 
@@ -448,6 +448,7 @@ __all__ = (
     "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
@@ -1804,6 +1805,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -1890,6 +1892,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -2244,3 +2247,27 @@ WaiterName = Literal[
     "vpn_connection_available",
     "vpn_connection_deleted",
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ap-southeast-3",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
